@@ -28,7 +28,7 @@ if($m_nRight <= 1) {
     $m_sContent .= div({align => 'center'}, translate('Failedinvalidcode'))       if $m_nSkipCaptch eq -3;
     $m_sContent .= qq(
     <div class="dbForm">
-    <img src="images/logo.png" alt="MySQL-Admin"/>
+    <img src="images/logo.png" alt="MySQL-Admin" onclick="location.href='http://lindnerei.sourceforge" style="cursor:pointer"/>
     <form name="login" id="loginForm" class="dbForm" target="_parent" method="get" name="Login"  onsubmit="submitForm(this,'ShowDatabases','ShowDatabases');return false;">
     <label for="user" class="caption">$name</label>
     <input type="text" id="user" data-regexp=").'/^\w{4,100}$/'.qq(" data-error="$wrong_username_text" data-right="$right_username_text" name="user"/>
