@@ -1,46 +1,46 @@
 $VAR1 = {
-          'cgi' => {
-                     'expires' => '+1y',
-                     'style' => 'mysql',
-                     'title' => 'MySQL::Admin',
-                     'bin' => '/var/www/cgi-bin',
-                     'serverName' => 'localhost',
-                     'cookiePath' => '/',
-                     'alias' => 'perl',
-                     'DocumentRoot' => '/var/www/htdocs'
-                   },
-          'uploads' => {
-                         'chmod' => 438,
-                         'maxlength' => 21000000,
-                         'path' => '/var/www/htdocs/download'
-                       },
-          'scriptAlias' => 'perl',
-          'floodtime' => 10,
-          'mod' => 1,
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'session' => '/var/www/cgi-bin/config/session.pl',
+          'version' => '0.87',
+          'files' => {
+                       'chmod' => '0755',
+                       'owner' => 'lze',
+                       'group' => 'lze'
+                     },
           'database' => {
-                          'password' => '',
-                          'CurrentPass' => '',
-                          'host' => 'localhost',
                           'name' => 'LZE',
-                          'CurrentHost' => 'localhost',
-                          'user' => 'root',
+                          'password' => '',
                           'CurrentDb' => 'LZE',
-                          'CurrentUser' => 'root'
+                          'host' => 'localhost',
+                          'CurrentHost' => 'localhost',
+                          'CurrentUser' => 'root',
+                          'CurrentPass' => '',
+                          'user' => 'root'
                         },
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'version' => '0.86',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'admin' => {
                        'password' => 'testpass'
                      },
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'files' => {
-                       'owner' => 'lze',
-                       'group' => 'lze',
-                       'chmod' => '0755'
-                     },
-          'language' => 'en'
+          'translate' => 'cgi-bin//config/translate.pl',
+          'actions' => 'cgi-bin//config/actions.pl',
+          'scriptAlias' => 'cgi-bin',
+          'uploads' => {
+                         'path' => '/var/www/htdocs/download',
+                         'chmod' => 438,
+                         'maxlength' => 21000000
+                       },
+          'config' => 'cgi-bin//config/settings.pl',
+          'session' => 'cgi-bin//config/session.pl',
+          'mod' => 'n',
+          'cgi' => {
+                     'style' => 'mysql',
+                     'expires' => '+1y',
+                     'cookiePath' => '/',
+                     'bin' => 'cgi-bin/',
+                     'DocumentRoot' => './',
+                     'title' => 'MySQL::Admin',
+                     'serverName' => 'localhost',
+                     'alias' => 'cgi-bin'
+                   },
+          'language' => 'en',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'floodtime' => 10
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
