@@ -1,7 +1,9 @@
 #!/usr/bin/perl -w
 use strict;
 use utf8;
+use warnings;
+#use CGI::Carp qw(fatalsToBrowser);
 use lib qw(lib);
 use MySQL::Admin::GUI;
-ContentHeader("cgi-bin//config/settings.pl");
+ContentHeader("%PATH%/config/settings.pl");
 print Body();
\ No newline at end of file
