@@ -8,133 +8,77 @@ CREATE TABLE `actions` (
   PRIMARY KEY (`id`),
   UNIQUE KEY `action_2` (`action`),
   KEY `action` (`action`)
-) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AddFulltext','tables.pl','AddFulltext','5','AddFulltext');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','AnalyzeTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','AddPrimaryKey');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChangeEngine','tables.pl','ChangeEngine','5','ChangeEngine');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','ChangeAutoInCrementValue');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChangeCol','tables.pl','ChangeCol','5','ChangeCol');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChangeCharset','tables.pl','ChangeCharset','5','ChangeCharset');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChooseDataBase','tables.pl','ChooseDataBase','5','ChooseDataBase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropTable','tables.pl','DropTable','5','DropTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DeleteEntry','tables.pl','DeleteEntry','5','DeleteEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropCol','tables.pl','DropCol','5','DropCol');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowDumpTable','tables.pl','DumpTable','5','ShowDumpTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ExecSql','tables.pl','ExecSql','5','ExecSql');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('EditTable','tables.pl','SQL','5','EditTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('EditEntry','tables.pl','EditEntry','5','EditEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('NewEntry','tables.pl','NewEntry','5','NewEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('NewTable','tables.pl','NewTable','5','NewTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('CreateDatabase','tables.pl','CreateDatabase','5','CreateDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('OptimizeTable','tables.pl','OptimizeTable','5','OptimizeTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('RepairTable','tables.pl','RepairTable','5','RepairTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveEditTable','tables.pl','SaveEditTable','5','SaveEditTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SQL','tables.pl','SQL','5','SQL');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveEntry','tables.pl','SaveEntry','5','SaveEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropFulltext','tables.pl','DropFulltext','5','DropFulltext');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowTables','tables.pl','ShowTables','5','ShowTables');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowTableDetails','tables.pl','ShowTableDetails','5','ShowTableDetails');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowTable','tables.pl','ShowTable','5','ShowTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('TruncateTable','tables.pl','TruncateTable','5','TruncateTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','ShowProcesslist');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AddIndex','tables.pl','AddIndex','5','AddIndex');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropIndex','tables.pl','DropFulltext','5','DropIndex');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AddUnique','tables.pl','DropFulltext','5','AddUnique');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowNewEntry','tables.pl','ShowNewEntry','5','ShowNewEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('MultipleAction','tables.pl','MultipleAction','5','MultipleAction');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowDumpDatabase','tables.pl','DumpDatabase','5','ShowDumpDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveNewTable','tables.pl','SaveNewTable','5','SaveNewTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('EditAction','tables.pl','EditAction','5','EditAction');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('MultipleDbAction','tables.pl','MultipleDbAction','5','MultipleDbAction');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('RenameTable','tables.pl','RenameTable','5','RenameTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveNewColumn','tables.pl','SaveNewColumn','5','SaveNewColumn');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('NewDatabase','tables.pl','NewDatabase','5','NewDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowEditIndex','tables.pl','ShowEditIndex','5','ShowEditIndex');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveNewIndex','tables.pl','SaveNewIndex','5','SaveNewIndex');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowRights','tables.pl','ShowRights','5','ShowRights');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveRights','tables.pl','SaveRights','5','SaveRights');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowUsers','tables.pl','ShowUsers','5','ShowUsers');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('CreateUser','tables.pl','CreateUser','5','CreateUser');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DeleteUser','tables.pl','DeleteUser','5','DeleteUser');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropDatabase','tables.pl','DropDatabase','5','DropDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowDatabases','tables.pl','ShowDatabases','5','ShowDatabases');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowVariables','tables.pl','ShowVariables','5','ShowVariables');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('searchDatabase','tables.pl','searchDatabase','5','searchDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('showLogin','exploit.pl','','0','main');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('showProfile','tables.pl','showProfile','5','showProfile');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('saveProfile','tables.pl','Profile','5','saveProfile');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('searchHelpTopic','tables.pl','Help Topic','5','searchHelpTopic');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('login','login.pl','Login','0','main');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('quickbar','quickbar.pl','quickbar','5','main');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowNewTable','tables.pl','ShowNewTable','5','ShowNewTable'); AUTO_INCREMENT=0 DEFAULT CHARSET=utf8;
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AddFulltext','tables.pl','AddFulltext','5','AddFulltext');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','AnalyzeTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','AddPrimaryKey');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChangeEngine','tables.pl','ChangeEngine','5','ChangeEngine');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','ChangeAutoInCrementValue');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChangeCol','tables.pl','ChangeCol','5','ChangeCol');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChangeCharset','tables.pl','ChangeCharset','5','ChangeCharset');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ChooseDataBase','tables.pl','ChooseDataBase','5','ChooseDataBase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropTable','tables.pl','DropTable','5','DropTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DeleteEntry','tables.pl','DeleteEntry','5','DeleteEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropCol','tables.pl','DropCol','5','DropCol');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowDumpTable','tables.pl','DumpTable','5','ShowDumpTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ExecSql','tables.pl','ExecSql','5','ExecSql');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('EditTable','tables.pl','SQL','5','EditTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('EditEntry','tables.pl','EditEntry','5','EditEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('NewEntry','tables.pl','NewEntry','5','NewEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('NewTable','tables.pl','NewTable','5','NewTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('CreateDatabase','tables.pl','CreateDatabase','5','CreateDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('OptimizeTable','tables.pl','OptimizeTable','5','OptimizeTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('RepairTable','tables.pl','RepairTable','5','RepairTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveEditTable','tables.pl','SaveEditTable','5','SaveEditTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SQL','tables.pl','SQL','5','SQL');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveEntry','tables.pl','SaveEntry','5','SaveEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropFulltext','tables.pl','DropFulltext','5','DropFulltext');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowTables','tables.pl','ShowTables','5','ShowTables');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowTableDetails','tables.pl','ShowTableDetails','5','ShowTableDetails');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowTable','tables.pl','ShowTable','5','ShowTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('TruncateTable','tables.pl','TruncateTable','5','TruncateTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','ShowProcesslist');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AddIndex','tables.pl','AddIndex','5','AddIndex');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropIndex','tables.pl','DropFulltext','5','DropIndex');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('AddUnique','tables.pl','DropFulltext','5','AddUnique');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowNewEntry','tables.pl','ShowNewEntry','5','ShowNewEntry');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('MultipleAction','tables.pl','MultipleAction','5','MultipleAction');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowDumpDatabase','tables.pl','DumpDatabase','5','ShowDumpDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveNewTable','tables.pl','SaveNewTable','5','SaveNewTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('EditAction','tables.pl','EditAction','5','EditAction');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('MultipleDbAction','tables.pl','MultipleDbAction','5','MultipleDbAction');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('RenameTable','tables.pl','RenameTable','5','RenameTable');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveNewColumn','tables.pl','SaveNewColumn','5','SaveNewColumn');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('NewDatabase','tables.pl','NewDatabase','5','NewDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowEditIndex','tables.pl','ShowEditIndex','5','ShowEditIndex');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveNewIndex','tables.pl','SaveNewIndex','5','SaveNewIndex');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowRights','tables.pl','ShowRights','5','ShowRights');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('SaveRights','tables.pl','SaveRights','5','SaveRights');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowUsers','tables.pl','ShowUsers','5','ShowUsers');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('CreateUser','tables.pl','CreateUser','5','CreateUser');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DeleteUser','tables.pl','DeleteUser','5','DeleteUser');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('DropDatabase','tables.pl','DropDatabase','5','DropDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowDatabases','tables.pl','ShowDatabases','5','ShowDatabases');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowVariables','tables.pl','ShowVariables','5','ShowVariables');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('searchDatabase','tables.pl','searchDatabase','5','searchDatabase');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('showLogin','exploit.pl','','0','main');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('showProfile','tables.pl','showProfile','5','showProfile');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('saveProfile','tables.pl','Profile','5','saveProfile');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('searchHelpTopic','tables.pl','Help Topic','5','searchHelpTopic');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('login','login.pl','Login','0','main');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('quickbar','quickbar.pl','quickbar','5','main');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`) values('ShowNewTable','tables.pl','ShowNewTable','5','ShowNewTable');
+) ENGINE=InnoDB AUTO_INCREMENT=3161 DEFAULT CHARSET=utf8;
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','AddFulltext','1');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','AnalyzeTable','2');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','AddPrimaryKey','3');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','ChangeEngine','4');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','ChangeAutoInCrementValue','5');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChangeCol','tables.pl','ChangeCol','5','ChangeCol','6');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChangeCharset','tables.pl','ChangeCharset','5','ChangeCharset','7');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChooseDataBase','tables.pl','ChooseDataBase','5','ChooseDataBase','8');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropTable','tables.pl','DropTable','5','DropTable','9');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','DeleteEntry','10');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropCol','tables.pl','DropCol','5','DropCol','11');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowDumpTable','tables.pl','DumpTable','5','ShowDumpTable','12');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ExecSql','tables.pl','ExecSql','5','ExecSql','13');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('EditTable','tables.pl','SQL','5','EditTable','14');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('EditEntry','tables.pl','EditEntry','5','EditEntry','15');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','NewEntry','16');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('NewTable','tables.pl','NewTable','5','NewTable','17');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('CreateDatabase','tables.pl','CreateDatabase','5','CreateDatabase','18');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('OptimizeTable','tables.pl','OptimizeTable','5','OptimizeTable','19');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('RepairTable','tables.pl','RepairTable','5','RepairTable','20');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveEditTable','tables.pl','SaveEditTable','5','SaveEditTable','21');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SQL','tables.pl','SQL','5','SQL','22');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','SaveEntry','23');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','DropFulltext','24');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowTables','tables.pl','ShowTables','5','ShowTables','25');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowTableDetails','tables.pl','ShowTableDetails','5','ShowTableDetails','26');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowTable','tables.pl','ShowTable','5','ShowTable','27');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('TruncateTable','tables.pl','TruncateTable','5','TruncateTable','28');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','ShowProcesslist','29');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddIndex','tables.pl','AddIndex','5','AddIndex','30');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropIndex','tables.pl','DropFulltext','5','DropIndex','31');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddUnique','tables.pl','DropFulltext','5','AddUnique','32');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowNewEntry','tables.pl','ShowNewEntry','5','ShowNewEntry','33');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('MultipleAction','tables.pl','MultipleAction','5','MultipleAction','34');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowDumpDatabase','tables.pl','DumpDatabase','5','ShowDumpDatabase','35');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveNewTable','tables.pl','SaveNewTable','5','SaveNewTable','36');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('EditAction','tables.pl','EditAction','5','EditAction','37');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('MultipleDbAction','tables.pl','MultipleDbAction','5','MultipleDbAction','38');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('RenameTable','tables.pl','RenameTable','5','RenameTable','39');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveNewColumn','tables.pl','SaveNewColumn','5','SaveNewColumn','40');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('NewDatabase','tables.pl','NewDatabase','5','NewDatabase','41');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowEditIndex','tables.pl','ShowEditIndex','5','ShowEditIndex','42');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveNewIndex','tables.pl','SaveNewIndex','5','SaveNewIndex','43');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowRights','tables.pl','ShowRights','5','ShowRights','44');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveRights','tables.pl','SaveRights','5','SaveRights','45');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowUsers','tables.pl','ShowUsers','5','ShowUsers','46');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('CreateUser','tables.pl','CreateUser','5','CreateUser','47');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DeleteUser','tables.pl','DeleteUser','5','DeleteUser','48');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropDatabase','tables.pl','DropDatabase','5','DropDatabase','49');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowDatabases','tables.pl','ShowDatabases','5','ShowDatabases','50');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','ShowVariables','51');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('searchDatabase','tables.pl','searchDatabase','5','searchDatabase','52');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showLogin','exploit.pl','','0','main','53');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showProfile','tables.pl','showProfile','5','showProfile','54');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('saveProfile','tables.pl','Profile','5','saveProfile','55');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('searchHelpTopic','tables.pl','Help Topic','5','searchHelpTopic','56');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('login','login.pl','Login','0','main','57');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('quickbar','quickbar.pl','quickbar','5','main','58');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','ShowNewTable','117');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('downLoadFile','tables.pl','downLoadFile','5','downLoadFile','1288');
+
 CREATE TABLE `actions_set` (
   `action` varchar(25) NOT NULL,
   `foreign_action` varchar(25) NOT NULL,
   `output_id` varchar(25) NOT NULL DEFAULT '25',
   `id` int(25) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`),
-  FOREIGN KEY (`foreign_action`) REFERENCES `actions` (`action`) ON DELETE CASCADE ON UPDATE CASCADE
-) ENGINE=InnoDB AUTO_INCREMENT=138 DEFAULT CHARSET=utf8;
+  KEY `foreign_action` (`foreign_action`),
+  CONSTRAINT `actions_set_ibfk_1` FOREIGN KEY (`foreign_action`) REFERENCES `actions` (`action`) ON DELETE CASCADE ON UPDATE CASCADE
+) ENGINE=InnoDB AUTO_INCREMENT=139 DEFAULT CHARSET=utf8;
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddFulltext','AddFulltext','content','1');
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AnalyzeTable','AnalyzeTable','content','2');
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddPrimaryKey','AddPrimaryKey','content','3');
@@ -271,6 +215,8 @@ INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('S
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showLogin','quickbar','menuBar','135');
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showProfile','quickbar','menuBar','136');
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('searchHelpTopic','quickbar','menuBar','137');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('downLoadFile','downLoadFile','content','138');
+
 CREATE TABLE `exploit` (
   `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
   `referer` text NOT NULL,
@@ -281,7 +227,12 @@ CREATE TABLE `exploit` (
   PRIMARY KEY (`id`),
   UNIQUE KEY `id` (`id`),
   FULLTEXT KEY `remote_addr` (`remote_addr`)
-) ENGINE=MyISAM AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM AUTO_INCREMENT=5 DEFAULT CHARSET=utf8;
+INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-06-26 07:09:49','http://localhost/?perl/mysql.pl?action=showDatabases','127.0.0.1','action=showDatabases','1','14');
+INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-06-27 10:52:29','http://localhost/?perl/mysql.pl?action=ShowTables','127.0.0.1','action=ShowTables','2','4');
+INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-06-25 18:28:13','http://localhost/?/perl/mysql.pl?action=logout','127.0.0.1','action=logout','3','2');
+INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-06-25 19:05:36','http://localhost/?perl/mysql.pl?action=ShowUsers','127.0.0.1','action=ShowUsers','4','2');
+
 CREATE TABLE `querys` (
   `title` varchar(100) NOT NULL DEFAULT '',
   `description` text NOT NULL,
@@ -290,6 +241,7 @@ CREATE TABLE `querys` (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+
 CREATE TABLE `reserved_words` (
   `reserved_word` varchar(50) DEFAULT NULL,
   `id` int(11) NOT NULL AUTO_INCREMENT,
@@ -518,6 +470,7 @@ INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARBINARY','220');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARYING','221');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHILE','222');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('XOR','223');
+
 CREATE TABLE `users` (
   `pass` text NOT NULL,
   `user` varchar(10) NOT NULL,
@@ -526,5 +479,5 @@ CREATE TABLE `users` (
   `ip` varchar(50) DEFAULT NULL,
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
-) ENGINE=MyISAM AUTO_INCREMENT=8 DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM AUTO_INCREMENT=14 DEFAULT CHARSET=utf8;
 INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','123','dd','1');
\ No newline at end of file
