@@ -35,7 +35,17 @@ function confirm2(txt,sub,arg,arg2,arg3)
     evt.stopPropagation();
   });
 }
-
+function errorPopUp(txt,sub,arg,arg2,arg3)
+{
+  visible('popup');
+  var sleep = true;
+  setText('popupContent','<b>'+txt+'</b><div align="right" style="padding:0.4em;">&#160;<input  type="submit" id="confirmButton" value="Ok"/></div>');
+  var node = $("confirmButton");
+  node.addEventListener ('click',function (evt){
+    hide('popup');
+    sub(arg,arg2,arg3);
+  });
+}
 function checkForm(form)
 {
   var selectElement = form.querySelectorAll('input');
@@ -301,7 +311,7 @@ function submitForm(node,tabId,tabTitle,bHistory,method,uri)
 {
     bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
     method   = typeof method   !== 'undefined' ? method   : 'POST';
-    var url  = typeof uri      !== 'undefined' ? uri      : "perl/mysql.pl?";
+    var url  = typeof uri      !== 'undefined' ? uri      : "%ALIAS%/mysql.pl?";
     if(checkForm(node)){
       var formData = new FormData();
       for(var i =0; i < node.elements.length;i++){
@@ -343,8 +353,8 @@ function submitForm(node,tabId,tabTitle,bHistory,method,uri)
   }
 }
 var http_request = false;
-var oldpage;
-//requestURI('perl/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
+var oldpage = 0;
+//requestURI('%ALIAS%/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
 function requestURI(url,id,txt,bHistory,formData,method,bWaid)
 {
       closePopup();
@@ -431,12 +441,11 @@ function setContent()
 		setText('content',oldpage);
 		setCurrentTab(currentId, currentTxt);
 	    }else{
-	      alert(http_request.status + " " +http_request.responseText);
-	      confirm2(http_request.responseText,errorMessage)
+	      errorPopUp('<div style="overflow:auto">'+http_request.status + " " +http_request.responseText+"</div>",errorMessage);
 	    }
-	      
+	    return false;
 	}
-      var closeButton = $("closeButton");
+     var closeButton = $("closeButton");
       if((!document.cookie.match('sid') || document.cookie.match('sid=123'))  && window.location.search.match('mysql.pl')  )
       {
 	showPopup('login',true);
@@ -482,9 +491,9 @@ function loadHistory()
     var uri = RegExp.$1;
     var url = window.location.search;
     if(uri && action){
-	requestURI('perl/mysql.pl'+uri,action,action,false);
+	requestURI('%ALIAS%/mysql.pl'+uri,action,action,false);
     }else
-      requestURI('perl/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
+      requestURI('%ALIAS%/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
     return true;
 }
 
