@@ -1,7 +1,6 @@
 package DBI::Library::Database;
 use strict;
-use warnings FATAL => 'all';
-no warnings 'redefine';
+use warnings;
 use utf8;
 use HTML::Entities;
 use vars qw( 
@@ -26,7 +25,7 @@ use DBI::Library qw(:all $m_dbh $m_dsn);
     'independent' => [qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute fetch_string)],
     'lze' => [ qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue) ],
 );
-$DBI::Library::Database::VERSION = '0.86';
+$DBI::Library::Database::VERSION = '0.87';
 $m_nSecs                         =  10;
 
 =head1 NAME
