@@ -2,8 +2,7 @@ package HTML::Menu::Pages;
 use Template::Quick;
 use strict;
 use utf8;
-use warnings FATAL => 'all';
-no warnings 'redefine';
+use warnings;
 require Exporter;
 use vars qw(
   $DefaultClass
@@ -22,7 +21,7 @@ use vars qw(
 );
 @HTML::Menu::Pages::EXPORT  = qw(makePages);
 @ISA                        = qw(Exporter);
-$HTML::Menu::Pages::VERSION = '0.86';
+$HTML::Menu::Pages::VERSION = '0.87';
 $DefaultClass               = 'HTML::Menu::Pages' unless defined $HTML::Menu::Pages::DefaultClass;
 
 =head1 NAME
